Bing
Description: Bing helps you turn information into action, making it faster and easier to go from searching to doing.

Download today’s image
Play today's quiz
Aerial view of Boudhanath stupa in Kathmandu, Nepal
© Maksim Semin/Shutterstock
Harvest season begins

## Image of the day

15 Jan 2020
Harvest season begins
© Maksim Semin/Shutterstock
Today we're in Khatmandu, Nepal, where the Boudhanath stupa stands out against the skyline. A UNESCO World Heritage site, the stupa is on the ancient trade route from Tibet - traders have rested and offered prayers here for centuries. Like all stupas, Boudhanath is a mound-like structure containing relics. It was first built sometime after the 600s, when Buddhism was first spreading through Tibet and Nepal. It's long been a major pilgrimage site for Buddhists, and is said to entomb the remains of Kassapa Buddha, one of the 29 named ancient Buddhas.
Learn more

Make Bing your homepage

## Experience beauty every day

Never miss a moment and keep search at your fingertips. Just set Bing as your browser's homepage with a few easy steps!